/* 
  Hole.h

  Barry McMullin <mcmullin@eeng.dcu.ie>
  03-OCT-1996


*/



#import "Particle.h"


@interface Hole : Particle

// Overridden class methods (see doc in Particle.m)

+(void) setClassMobilityFactor: (double) inMobilityFactor;
+(double) getClassMobilityFactor;
+(void) setClassColor: (Color) color;
+(Color) getClassColor;



-drawSelfOn: (id <Raster>) r;

@end
